@@ -125,7 +125,7 @@ int main(int argc, char *argv[])
   if(opc == "lr")
   {
     if (have_vl) {
-      std::cout << "Error: -l specified, but mode is lr" << std::endl;
+      std::cerr << "Error: -l specified, but mode is lr" << std::endl;
       cli.print_usage();
     }
     if(ttype == 'a')
@@ -144,7 +144,7 @@ int main(int argc, char *argv[])
   else if(opc == "rl")
   {
     if (have_vr) {
-      std::cout << "Error: -r specified, but mode is rl" << std::endl;
+      std::cerr << "Error: -r specified, but mode is rl" << std::endl;
       cli.print_usage();
     }
     if(ttype == 'a')
