@@ -113,9 +113,9 @@ private:
 
   /**
    * Make a transition, but overriding the output symbol
-   * @param input symbol
-   * @param output symbol we expect to appear
-   * @param output symbol we want to appear
+   * @param input symbol read from infile
+   * @param output symbol from the FST
+   * @param output symbol we want to appear in outfile
    */
   void apply_override(int const input, int const old_sym, int const new_sym);
 
@@ -201,6 +201,10 @@ public:
 
   void step_case_override(const int val, const bool caseSensitive);
 
+  void step_optional(UChar32 val);
+
+  void closure(const sorted_vector<int32_t>& symbols);
+
   /**
    * Init the state with the initial node and empty output
    * @param initial the initial node of the transducer
@@ -222,6 +226,12 @@ public:
     */
   void pruneStatesWithForbiddenSymbol(int forbiddenSymbol);
 
+  /**
+   * Remove states not containing a particular symbol
+   * @param symbol the symbol that is required
+   */
+  void requireSymbol(int32_t symbol);
+
   /**
     * Whether any of the analyses contains a certain symbol
     * @param requiredSymbol the symbol we're looking for
@@ -271,6 +281,20 @@ public:
                        bool firstupper = false,
                        int firstchar = 0) const;
 
+  /**
+   * filterFinals(), but write the results into `result`
+   */
+  void filterFinalsArray(std::vector<UString>& result,
+                         std::map<Node *, double> const &finals,
+                         Alphabet const &a,
+                         std::set<UChar32> const &escaped_chars,
+                         bool display_weights = false,
+                         int max_analyses = INT_MAX,
+                         int max_weight_classes = INT_MAX,
+                         bool uppercase = false,
+                         bool firstupper = false,
+                         int firstchar = 0) const;
+
   /**
    * Same as previous one, but  the output is adapted to the SAO system
    * @param finals the set of final nodes
@@ -343,6 +367,11 @@ public:
                          std::queue<UString> &blanks,
                          std::vector<UString> &numbers) const;
 
+  /**
+   * Add all paths in other to self
+   */
+  void merge(const State& other);
+
 };
 
 #endif
